==> elephant-archives-domain-0.0.623-sources.jar: com/xforceplus/ultraman/app/elephantarchives/entity/Detection.java <==
package com.xforceplus.ultraman.app.elephantarchives.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2021-10-09
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class Detection implements Serializable {

  private static final long serialVersionUID=1L;

  private Long voucherId;

  private String voucherNo;

  private String detectionStatus;

  private String detectionUser;

  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime detectionEndTime;

  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime detectionStartTime;

  private String zipUrl;

  private String zipName;

  private String pdfUrl;

  private String pdfName;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private String detectionResult;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("voucher_id", voucherId);
      map.put("voucher_no", voucherNo);
      map.put("detection_status", detectionStatus);
      map.put("detection_user", detectionUser);
      map.put("detection_end_time", BocpGenUtils.toTimestamp(detectionEndTime));
      map.put("detection_start_time", BocpGenUtils.toTimestamp(detectionStartTime));
      map.put("zip_url", zipUrl);
      map.put("zip_name", zipName);
      map.put("pdf_url", pdfUrl);
      map.put("pdf_name", pdfName);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("detection_result", detectionResult);
      return map;
  }

  public static Detection fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    Detection entity = new Detection();
    if(map.containsKey("voucher_id")) {
      Object obj = map.get("voucher_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setVoucherId((Long)obj);
        } else if(obj instanceof String) {
          entity.setVoucherId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setVoucherId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("voucher_no")) {
      Object obj = map.get("voucher_no");
      if(obj != null) {
        if(obj instanceof String){
          entity.setVoucherNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("detection_status")) {
      Object obj = map.get("detection_status");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDetectionStatus((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("detection_user")) {
      Object obj = map.get("detection_user");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDetectionUser((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("detection_end_time")) {
      Object obj = map.get("detection_end_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setDetectionEndTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setDetectionEndTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setDetectionEndTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setDetectionEndTime(null);
      }
    }
    if(map.containsKey("detection_start_time")) {
      Object obj = map.get("detection_start_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setDetectionStartTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setDetectionStartTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setDetectionStartTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setDetectionStartTime(null);
      }
    }
    if(map.containsKey("zip_url")) {
      Object obj = map.get("zip_url");
      if(obj != null) {
        if(obj instanceof String){
          entity.setZipUrl((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("zip_name")) {
      Object obj = map.get("zip_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setZipName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pdf_url")) {
      Object obj = map.get("pdf_url");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPdfUrl((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pdf_name")) {
      Object obj = map.get("pdf_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPdfName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("detection_result")) {
      Object obj = map.get("detection_result");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDetectionResult((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}

==> elephant-archives-domain-0.0.628-sources.jar: com/xforceplus/ultraman/app/elephantarchives/entity/Detection.java <==
package com.xforceplus.ultraman.app.elephantarchives.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2021-10-12
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class Detection implements Serializable {

  private static final long serialVersionUID=1L;

  private Long voucherId;

  private String voucherNo;

  private String detectionStatus;

  private String detectionUser;

  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime detectionEndTime;

  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime detectionStartTime;

  private String zipUrl;

  private String zipName;

  private String pdfUrl;

  private String pdfName;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private String detectionResult;

  private String abstractText;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("voucher_id", voucherId);
      map.put("voucher_no", voucherNo);
      map.put("detection_status", detectionStatus);
      map.put("detection_user", detectionUser);
      map.put("detection_end_time", BocpGenUtils.toTimestamp(detectionEndTime));
      map.put("detection_start_time", BocpGenUtils.toTimestamp(detectionStartTime));
      map.put("zip_url", zipUrl);
      map.put("zip_name", zipName);
      map.put("pdf_url", pdfUrl);
      map.put("pdf_name", pdfName);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("detection_result", detectionResult);
      map.put("abstract_text", abstractText);
      return map;
  }

  public static Detection fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    Detection entity = new Detection();
    if(map.containsKey("voucher_id")) {
      Object obj = map.get("voucher_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setVoucherId((Long)obj);
        } else if(obj instanceof String) {
          entity.setVoucherId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setVoucherId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("voucher_no")) {
      Object obj = map.get("voucher_no");
      if(obj != null) {
        if(obj instanceof String){
          entity.setVoucherNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("detection_status")) {
      Object obj = map.get("detection_status");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDetectionStatus((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("detection_user")) {
      Object obj = map.get("detection_user");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDetectionUser((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("detection_end_time")) {
      Object obj = map.get("detection_end_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setDetectionEndTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setDetectionEndTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setDetectionEndTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setDetectionEndTime(null);
      }
    }
    if(map.containsKey("detection_start_time")) {
      Object obj = map.get("detection_start_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setDetectionStartTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setDetectionStartTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setDetectionStartTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setDetectionStartTime(null);
      }
    }
    if(map.containsKey("zip_url")) {
      Object obj = map.get("zip_url");
      if(obj != null) {
        if(obj instanceof String){
          entity.setZipUrl((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("zip_name")) {
      Object obj = map.get("zip_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setZipName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pdf_url")) {
      Object obj = map.get("pdf_url");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPdfUrl((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pdf_name")) {
      Object obj = map.get("pdf_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPdfName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("detection_result")) {
      Object obj = map.get("detection_result");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDetectionResult((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("abstract_text")) {
      Object obj = map.get("abstract_text");
      if(obj != null) {
        if(obj instanceof String){
          entity.setAbstractText((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}
